searchData={"items":[{"type":"module","title":"Dspy","doc":"Elixir implementation of DSPy - a framework for algorithmically optimizing LM prompts and weights.\n\nDSPy provides a unified interface for composing LM programs with automatic optimization.","ref":"Dspy.html"},{"type":"module","title":"Core Components - Dspy","doc":"- `Dspy.Signature` - Define typed input/output interfaces for LM calls\n- `Dspy.Module` - Composable building blocks for LM programs  \n- `Dspy.Predict` - Basic prediction modules\n- `Dspy.ChainOfThought` - Step-by-step reasoning\n- `Dspy.LM` - Language model client abstraction\n- `Dspy.Example` - Training examples and data structures\n- `Dspy.Teleprompter` - Prompt optimization algorithms","ref":"Dspy.html#module-core-components"},{"type":"module","title":"Quick Start - Dspy","doc":"# Configure language model\n    Dspy.configure(lm: %Dspy.LM.OpenAI{model: \"gpt-4.1\"})\n\n    # Define signature\n    defmodule QA do\n      use Dspy.Signature\n      input_field :question, :string, \"Question to answer\"\n      output_field :answer, :string, \"Answer to the question\"\n    end\n\n    # Create and use module\n    predict = Dspy.Predict.new(QA)\n    result = Dspy.Module.forward(predict, %{question: \"What is 2+2?\"})","ref":"Dspy.html#module-quick-start"},{"type":"function","title":"Dspy.configure/1","doc":"Configure global DSPy settings.","ref":"Dspy.html#configure/1"},{"type":"function","title":"Options - Dspy.configure/1","doc":"- `:lm` - Language model client (required)\n- `:max_tokens` - Maximum tokens per generation (default: 2048)\n- `:temperature` - Sampling temperature (default: 0.0)\n- `:cache` - Enable response caching (default: true)","ref":"Dspy.html#configure/1-options"},{"type":"function","title":"Dspy.example/1","doc":"Create a new Example with the given attributes.","ref":"Dspy.html#example/1"},{"type":"function","title":"Dspy.prediction/1","doc":"Create a new Prediction with the given attributes.","ref":"Dspy.html#prediction/1"},{"type":"function","title":"Dspy.settings/0","doc":"Get current DSPy configuration.","ref":"Dspy.html#settings/0"},{"type":"module","title":"Dspy.ChainOfThought","doc":"Chain of Thought reasoning module.\n\nExtends basic prediction with step-by-step reasoning by adding\na reasoning field to the signature and encouraging the model\nto show its work before generating the final answer.","ref":"Dspy.ChainOfThought.html"},{"type":"function","title":"Dspy.ChainOfThought.new/2","doc":"Create a new ChainOfThought module.","ref":"Dspy.ChainOfThought.html#new/2"},{"type":"function","title":"Dspy.ChainOfThought.parameters/1","doc":"Callback implementation for  Dspy.Module.parameters/1 .","ref":"Dspy.ChainOfThought.html#parameters/1"},{"type":"type","title":"Dspy.ChainOfThought.t/0","doc":"","ref":"Dspy.ChainOfThought.html#t:t/0"},{"type":"function","title":"Dspy.ChainOfThought.update_parameters/2","doc":"Callback implementation for  Dspy.Module.update_parameters/2 .","ref":"Dspy.ChainOfThought.html#update_parameters/2"},{"type":"module","title":"Dspy.Example","doc":"Training examples for DSPy programs.\n\nExamples represent input-output pairs used for few-shot learning,\noptimization, and evaluation. They support flexible attribute access\nand can contain arbitrary fields.","ref":"Dspy.Example.html"},{"type":"function","title":"Dspy.Example.delete/2","doc":"Delete an attribute from the example.","ref":"Dspy.Example.html#delete/2"},{"type":"function","title":"Dspy.Example.get/3","doc":"Get an attribute from the example.","ref":"Dspy.Example.html#get/3"},{"type":"function","title":"Dspy.Example.keys/1","doc":"Get all attribute keys.","ref":"Dspy.Example.html#keys/1"},{"type":"function","title":"Dspy.Example.merge/2","doc":"Merge two examples, with the second taking precedence.","ref":"Dspy.Example.html#merge/2"},{"type":"function","title":"Dspy.Example.new/2","doc":"Create a new Example with the given attributes.","ref":"Dspy.Example.html#new/2"},{"type":"function","title":"Examples - Dspy.Example.new/2","doc":"iex> ex = Dspy.Example.new(%{question: \"What is 2+2?\", answer: \"4\"})\n    iex> ex.question\n    \"What is 2+2?\"\n\n    iex> ex = Dspy.Example.new(question: \"What is 2+2?\", answer: \"4\")\n    iex> ex.answer\n    \"4\"","ref":"Dspy.Example.html#new/2-examples"},{"type":"function","title":"Dspy.Example.put/3","doc":"Put an attribute in the example.","ref":"Dspy.Example.html#put/3"},{"type":"type","title":"Dspy.Example.t/0","doc":"","ref":"Dspy.Example.html#t:t/0"},{"type":"function","title":"Dspy.Example.to_map/1","doc":"Convert example to a map.","ref":"Dspy.Example.html#to_map/1"},{"type":"behaviour","title":"Dspy.LM","doc":"Behaviour for language model clients.\n\nDefines the interface for interacting with different language model providers\nlike OpenAI, Anthropic, local models, etc.","ref":"Dspy.LM.html"},{"type":"function","title":"Dspy.LM.assistant_message/1","doc":"Create an assistant message.","ref":"Dspy.LM.html#assistant_message/1"},{"type":"function","title":"Dspy.LM.generate/1","doc":"Generate a completion using the configured language model.","ref":"Dspy.LM.html#generate/1"},{"type":"function","title":"Dspy.LM.generate/2","doc":"Generate a completion using a specific language model.","ref":"Dspy.LM.html#generate/2"},{"type":"callback","title":"Dspy.LM.generate/2","doc":"Generate a completion from the language model.","ref":"Dspy.LM.html#c:generate/2"},{"type":"function","title":"Dspy.LM.generate_text/2","doc":"Generate text from a simple prompt string.","ref":"Dspy.LM.html#generate_text/2"},{"type":"type","title":"Dspy.LM.message/0","doc":"","ref":"Dspy.LM.html#t:message/0"},{"type":"function","title":"Dspy.LM.message/2","doc":"Create a chat message.","ref":"Dspy.LM.html#message/2"},{"type":"type","title":"Dspy.LM.request/0","doc":"","ref":"Dspy.LM.html#t:request/0"},{"type":"type","title":"Dspy.LM.response/0","doc":"","ref":"Dspy.LM.html#t:response/0"},{"type":"function","title":"Dspy.LM.supports?/2","doc":"Check if a language model supports a feature.","ref":"Dspy.LM.html#supports?/2"},{"type":"callback","title":"Dspy.LM.supports?/2","doc":"Check if the language model supports a specific feature.","ref":"Dspy.LM.html#c:supports?/2"},{"type":"function","title":"Dspy.LM.system_message/1","doc":"Create a system message.","ref":"Dspy.LM.html#system_message/1"},{"type":"type","title":"Dspy.LM.t/0","doc":"","ref":"Dspy.LM.html#t:t/0"},{"type":"function","title":"Dspy.LM.user_message/1","doc":"Create a user message.","ref":"Dspy.LM.html#user_message/1"},{"type":"module","title":"Dspy.LM.OpenAI","doc":"OpenAI language model client.\n\nIntegrates with OpenAI's Chat Completions API to provide\nlanguage model capabilities for DSPy.","ref":"Dspy.LM.OpenAI.html"},{"type":"function","title":"Dspy.LM.OpenAI.new/1","doc":"Create a new OpenAI client.","ref":"Dspy.LM.OpenAI.html#new/1"},{"type":"type","title":"Dspy.LM.OpenAI.t/0","doc":"","ref":"Dspy.LM.OpenAI.html#t:t/0"},{"type":"behaviour","title":"Dspy.Module","doc":"Behaviour for composable DSPy modules.\n\nModules are the building blocks of DSPy programs. They define\nforward passes for inference and can contain optimizable parameters.","ref":"Dspy.Module.html"},{"type":"function","title":"Dspy.Module.compose/1","doc":"Compose multiple modules in sequence.","ref":"Dspy.Module.html#compose/1"},{"type":"function","title":"Dspy.Module.forward/2","doc":"Execute a module's forward pass.","ref":"Dspy.Module.html#forward/2"},{"type":"callback","title":"Dspy.Module.forward/2","doc":"Execute the module's forward pass.","ref":"Dspy.Module.html#c:forward/2"},{"type":"type","title":"Dspy.Module.inputs/0","doc":"","ref":"Dspy.Module.html#t:inputs/0"},{"type":"type","title":"Dspy.Module.outputs/0","doc":"","ref":"Dspy.Module.html#t:outputs/0"},{"type":"function","title":"Dspy.Module.parallel/1","doc":"Run modules in parallel and merge results.","ref":"Dspy.Module.html#parallel/1"},{"type":"function","title":"Dspy.Module.parameters/1","doc":"Get a module's parameters if it implements the callback.","ref":"Dspy.Module.html#parameters/1"},{"type":"callback","title":"Dspy.Module.parameters/1","doc":"Get the module's optimizable parameters.","ref":"Dspy.Module.html#c:parameters/1"},{"type":"type","title":"Dspy.Module.t/0","doc":"","ref":"Dspy.Module.html#t:t/0"},{"type":"function","title":"Dspy.Module.update_parameters/2","doc":"Update a module's parameters if it implements the callback.","ref":"Dspy.Module.html#update_parameters/2"},{"type":"callback","title":"Dspy.Module.update_parameters/2","doc":"Update the module with new parameters.","ref":"Dspy.Module.html#c:update_parameters/2"},{"type":"module","title":"Dspy.Parameter","doc":"Optimizable parameters for DSPy modules.\n\nParameters represent components that can be optimized by teleprompters,\nsuch as prompts, few-shot examples, and model weights.","ref":"Dspy.Parameter.html"},{"type":"function","title":"Dspy.Parameter.history/1","doc":"Get the parameter's history of values.","ref":"Dspy.Parameter.html#history/1"},{"type":"function","title":"Dspy.Parameter.new/4","doc":"Create a new parameter.","ref":"Dspy.Parameter.html#new/4"},{"type":"type","title":"Dspy.Parameter.parameter_type/0","doc":"","ref":"Dspy.Parameter.html#t:parameter_type/0"},{"type":"function","title":"Dspy.Parameter.revert/1","doc":"Revert to the previous value.","ref":"Dspy.Parameter.html#revert/1"},{"type":"type","title":"Dspy.Parameter.t/0","doc":"","ref":"Dspy.Parameter.html#t:t/0"},{"type":"function","title":"Dspy.Parameter.update/2","doc":"Update a parameter's value.","ref":"Dspy.Parameter.html#update/2"},{"type":"function","title":"Dspy.Parameter.value/1","doc":"Get the parameter's current value.","ref":"Dspy.Parameter.html#value/1"},{"type":"module","title":"Dspy.Predict","doc":"Basic prediction module for DSPy.\n\nThe Predict module takes a signature and generates predictions\nby constructing prompts and calling the language model.","ref":"Dspy.Predict.html"},{"type":"function","title":"Dspy.Predict.new/2","doc":"Create a new Predict module.","ref":"Dspy.Predict.html#new/2"},{"type":"function","title":"Dspy.Predict.parameters/1","doc":"Callback implementation for  Dspy.Module.parameters/1 .","ref":"Dspy.Predict.html#parameters/1"},{"type":"type","title":"Dspy.Predict.t/0","doc":"","ref":"Dspy.Predict.html#t:t/0"},{"type":"function","title":"Dspy.Predict.update_parameters/2","doc":"Callback implementation for  Dspy.Module.update_parameters/2 .","ref":"Dspy.Predict.html#update_parameters/2"},{"type":"module","title":"Dspy.Prediction","doc":"Language model predictions with completion metadata.\n\nPredictions represent the outputs from language model calls,\nincluding the generated content and metadata about the generation process.","ref":"Dspy.Prediction.html"},{"type":"function","title":"Dspy.Prediction.add_completion/2","doc":"Add completion metadata to the prediction.","ref":"Dspy.Prediction.html#add_completion/2"},{"type":"type","title":"Dspy.Prediction.completion/0","doc":"","ref":"Dspy.Prediction.html#t:completion/0"},{"type":"function","title":"Dspy.Prediction.completions/1","doc":"Get all completions.","ref":"Dspy.Prediction.html#completions/1"},{"type":"function","title":"Dspy.Prediction.delete/2","doc":"Delete an attribute from the prediction.","ref":"Dspy.Prediction.html#delete/2"},{"type":"function","title":"Dspy.Prediction.get/3","doc":"Get an attribute from the prediction.","ref":"Dspy.Prediction.html#get/3"},{"type":"function","title":"Dspy.Prediction.keys/1","doc":"Get all attribute keys.","ref":"Dspy.Prediction.html#keys/1"},{"type":"function","title":"Dspy.Prediction.latest_completion/1","doc":"Get the most recent completion.","ref":"Dspy.Prediction.html#latest_completion/1"},{"type":"function","title":"Dspy.Prediction.new/3","doc":"Create a new Prediction with the given attributes.","ref":"Dspy.Prediction.html#new/3"},{"type":"function","title":"Examples - Dspy.Prediction.new/3","doc":"iex> pred = Dspy.Prediction.new(%{answer: \"4\"})\n    iex> pred.answer\n    \"4\"\n\n    iex> pred = Dspy.Prediction.new(answer: \"4\", reasoning: \"2+2=4\")\n    iex> pred.reasoning\n    \"2+2=4\"","ref":"Dspy.Prediction.html#new/3-examples"},{"type":"function","title":"Dspy.Prediction.put/3","doc":"Put an attribute in the prediction.","ref":"Dspy.Prediction.html#put/3"},{"type":"type","title":"Dspy.Prediction.t/0","doc":"","ref":"Dspy.Prediction.html#t:t/0"},{"type":"function","title":"Dspy.Prediction.to_map/1","doc":"Convert prediction to a map.","ref":"Dspy.Prediction.html#to_map/1"},{"type":"module","title":"Dspy.Settings","doc":"Global configuration management for DSPy.\n\nMaintains settings like language model configuration, generation parameters,\nand optimization settings in a GenServer for thread-safe access.","ref":"Dspy.Settings.html"},{"type":"function","title":"Dspy.Settings.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Dspy.Settings.html#child_spec/1"},{"type":"function","title":"Dspy.Settings.configure/1","doc":"Configure global DSPy settings.","ref":"Dspy.Settings.html#configure/1"},{"type":"function","title":"Dspy.Settings.get/0","doc":"Get current settings.","ref":"Dspy.Settings.html#get/0"},{"type":"function","title":"Dspy.Settings.get/1","doc":"Get a specific setting.","ref":"Dspy.Settings.html#get/1"},{"type":"function","title":"Dspy.Settings.start_link/1","doc":"","ref":"Dspy.Settings.html#start_link/1"},{"type":"type","title":"Dspy.Settings.t/0","doc":"","ref":"Dspy.Settings.html#t:t/0"},{"type":"module","title":"Dspy.Signature","doc":"Define typed input/output interfaces for language model calls.\n\nSignatures specify the expected inputs and outputs for DSPy modules,\nincluding field types, descriptions, and validation rules.","ref":"Dspy.Signature.html"},{"type":"type","title":"Dspy.Signature.field/0","doc":"","ref":"Dspy.Signature.html#t:field/0"},{"type":"function","title":"Dspy.Signature.new/2","doc":"Create a new signature.","ref":"Dspy.Signature.html#new/2"},{"type":"function","title":"Dspy.Signature.parse_outputs/2","doc":"Parse outputs according to the signature.","ref":"Dspy.Signature.html#parse_outputs/2"},{"type":"type","title":"Dspy.Signature.t/0","doc":"","ref":"Dspy.Signature.html#t:t/0"},{"type":"function","title":"Dspy.Signature.to_prompt/2","doc":"Generate a prompt template from the signature.","ref":"Dspy.Signature.html#to_prompt/2"},{"type":"function","title":"Dspy.Signature.validate_inputs/2","doc":"Validate inputs against the signature.","ref":"Dspy.Signature.html#validate_inputs/2"},{"type":"module","title":"Dspy.Signature.DSL","doc":"DSL for defining DSPy signatures using macros.","ref":"Dspy.Signature.DSL.html"},{"type":"macro","title":"Dspy.Signature.DSL.input_field/4","doc":"Define an input field for the signature.","ref":"Dspy.Signature.DSL.html#input_field/4"},{"type":"macro","title":"Dspy.Signature.DSL.output_field/4","doc":"Define an output field for the signature.","ref":"Dspy.Signature.DSL.html#output_field/4"},{"type":"macro","title":"Dspy.Signature.DSL.signature_description/1","doc":"Set the signature description.","ref":"Dspy.Signature.DSL.html#signature_description/1"},{"type":"macro","title":"Dspy.Signature.DSL.signature_instructions/1","doc":"Set signature instructions.","ref":"Dspy.Signature.DSL.html#signature_instructions/1"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}